@@ -4,7 +4,7 @@
 //!
 //! ```rust
 //! # #[async_std::main] async fn main() -> Result<(), Box<dyn std::error::Error>> {
-//! let client = ytextract::Client::new().await?;
+//! let client = ytextract::Client::new();
 //!
 //! let streams = client.streams("nI2e-J6fsuk".parse()?).await?;
 //!
@@ -24,58 +24,35 @@ pub use self::audio::Stream as Audio;
 pub use self::common::Stream as Common;
 pub use self::video::Stream as Video;
 pub use crate::youtube::player_response::Quality;
-use crate::{
-    youtube::player_response::{FormatType, StreamingData},
-    Client,
-};
-use reqwest::Url;
-use std::{collections::HashMap, sync::Arc};
+use crate::{youtube::player_response::FormatType, Client};
 
 pub(crate) async fn get(
-    client: Arc<Client>,
+    client: Client,
     id: crate::video::Id,
-    streaming_data: Option<StreamingData>,
 ) -> crate::Result<impl Iterator<Item = Stream>> {
-    let streaming_data = if let Some(streaming_data) = streaming_data {
-        streaming_data
-    } else {
-        client.api.streams(id).await?.into_std()?
-    };
-
-    let needs_player = streaming_data
-        .adaptive_formats
-        .iter()
-        .any(|f| f.base.url.is_none());
-
-    if needs_player {
-        client.init_player().await;
-    }
+    let streaming_data = client.api.streams(id).await?.into_std()?;
 
     // TODO: DashManifest/HlsManifest
     Ok(streaming_data
         .adaptive_formats
         .into_iter()
-        .map(move |stream| Stream::new(stream, Arc::clone(&client))))
+        .map(move |stream| Stream::new(stream, client.clone())))
 }
 
 /// A Stream of a YouTube video
 #[derive(Clone)]
 pub enum Stream {
-    /// A [`Audio`]
+    /// A Stream exclusively containing [`Audio`] data
     Audio(Audio),
-    /// A [`Video`]
+    /// A Stream exclusively containing [`Video`] data
     Video(Video),
 }
 
 impl Stream {
-    pub(crate) fn new(
-        format: crate::youtube::player_response::Format,
-        client: Arc<Client>,
-    ) -> Self {
+    pub(crate) fn new(format: crate::youtube::player_response::Format, client: Client) -> Self {
         match format.ty {
             FormatType::Audio(audio) => Self::Audio(Audio {
                 common: Common {
-                    url: Self::resolve_url(&client, &format.base),
                     format: format.base,
                     client,
                 },
@@ -83,7 +60,6 @@ impl Stream {
             }),
             FormatType::Video(video) => Self::Video(Video {
                 common: Common {
-                    url: Self::resolve_url(&client, &format.base),
                     format: format.base,
                     client,
                 },
@@ -92,37 +68,6 @@ impl Stream {
         }
     }
 
-    fn resolve_url(
-        client: &Arc<Client>,
-        format: &crate::youtube::player_response::CommonFormat,
-    ) -> Url {
-        match &format.url {
-            Some(url) => url.clone(),
-            None => {
-                let signature_cipher = format
-                    .signature_cipher
-                    .as_ref()
-                    .expect("Stream did not have a URL or signatureCipher");
-                let root: HashMap<String, String> =
-                    serde_urlencoded::from_str(signature_cipher.as_str())
-                        .expect("signatureCipher was not urlencoded");
-
-                let signature = client.player().cipher().run(root["s"].clone());
-                let signature_arg = &root["sp"];
-                let mut url = Url::parse(&root["url"])
-                    .expect("signatureCipher url attribute was not a valid URL");
-
-                let query = url
-                    .query()
-                    .map(|q| format!("{}&{}={}", q, signature_arg, signature))
-                    .expect("URL did not have a query");
-
-                url.set_query(Some(&query));
-                url
-            }
-        }
-    }
-
     /// Returns `true` if the stream is [`Self::Audio`].
     pub fn is_audio(&self) -> bool {
         matches!(self, Self::Audio(..))
