@@ -4,7 +4,7 @@ use chrono::{DateTime, Utc};
 use reqwest::Url;
 use serde::Deserialize;
 
-#[derive(Debug, Deserialize)]
+#[derive(Deserialize)]
 #[serde(rename_all = "camelCase", untagged)]
 pub enum StreamResult {
     Ok {
@@ -28,7 +28,7 @@ impl StreamResult {
     }
 }
 
-#[derive(Debug, Deserialize)]
+#[derive(Deserialize)]
 #[serde(rename_all = "camelCase", untagged)]
 pub enum Result {
     Ok(PlayerResponse),
@@ -49,16 +49,14 @@ impl Result {
     }
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct PlayerResponse {
-    pub streaming_data: Option<StreamingData>,
     pub video_details: VideoDetails,
-    pub microformat: Microformat,
 }
 
 #[serde_with::serde_as]
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct VideoDetails {
     pub title: String,
@@ -83,41 +81,20 @@ pub struct VideoDetails {
     pub thumbnail: Thumbnail,
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct Thumbnail {
     pub thumbnails: Vec<crate::Thumbnail>,
 }
 
-#[derive(Debug, Deserialize, Clone)]
-#[serde(rename_all = "camelCase")]
-pub struct Microformat {
-    pub player_microformat_renderer: PlayerMicroformatRenderer,
-}
-
-#[serde_with::serde_as]
-#[derive(Debug, Deserialize, Clone)]
-#[serde(rename_all = "camelCase")]
-pub struct PlayerMicroformatRenderer {
-    // Nonexistant == not family safe
-    #[serde(default)]
-    pub is_family_safe: bool,
-    pub is_unlisted: bool,
-    pub category: String,
-    #[serde_as(as = "serde_with::DisplayFromStr")]
-    pub publish_date: chrono::NaiveDate,
-    #[serde_as(as = "serde_with::DisplayFromStr")]
-    pub upload_date: chrono::NaiveDate,
-}
-
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct StreamingData {
     #[serde(default)]
     pub adaptive_formats: Vec<Format>,
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 pub struct Format {
     #[serde(flatten)]
     pub base: CommonFormat,
@@ -126,13 +103,11 @@ pub struct Format {
 }
 
 #[serde_with::serde_as]
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct CommonFormat {
-    #[serde_as(as = "Option<serde_with::DisplayFromStr>")]
-    #[serde(default)]
-    pub url: Option<Url>,
-    pub signature_cipher: Option<String>,
+    #[serde_as(as = "serde_with::DisplayFromStr")]
+    pub url: Url,
     pub quality: Quality,
     pub projection_type: String,
     pub mime_type: String,
@@ -152,14 +127,14 @@ pub struct CommonFormat {
     pub index_range: Option<Range>,
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(untagged)]
 pub enum FormatType {
     Audio(AudioFormat),
     Video(VideoFormat),
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct VideoFormat {
     pub width: u64,
@@ -169,7 +144,7 @@ pub struct VideoFormat {
 }
 
 #[serde_with::serde_as]
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct AudioFormat {
     pub loudness_db: Option<f64>,
@@ -180,7 +155,7 @@ pub struct AudioFormat {
 }
 
 #[serde_with::serde_as]
-#[derive(Debug, serde::Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct Range {
     #[serde_as(as = "serde_with::DisplayFromStr")]
@@ -191,7 +166,7 @@ pub struct Range {
 
 /// The quality of a Stream
 #[allow(missing_docs)]
-#[derive(Debug, serde::Deserialize, PartialEq, Eq, Clone, Copy, PartialOrd, Ord)]
+#[derive(Debug, Deserialize, PartialEq, Eq, Clone, Copy, PartialOrd, Ord)]
 #[serde(rename_all = "lowercase")]
 #[non_exhaustive]
 pub enum Quality {
@@ -206,97 +181,33 @@ pub enum Quality {
     HD2160,
 }
 
-#[derive(Debug, serde::Deserialize)]
+#[derive(Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct PlayabilityStatus {
     pub status: String,
-    pub reason: Option<String>,
-    pub error_screen: Option<ErrorScreen>,
+    pub reason: String,
 }
 
 impl PlayabilityStatus {
     fn as_error(&self) -> crate::error::Youtube {
         use crate::error::Youtube;
 
-        match (self.reason.as_ref(), self.error_screen.as_ref()) {
-            (_, Some(ErrorScreen { player_error_message_renderer: Some(renderer)})) => {
-                match renderer.reason.simple_text.as_str() {
-                    "Private video" => Youtube::Private,
-                    "Video unavailable" => match renderer.subreason().unwrap_or("This video is unavailable") {
-                        "This video is no longer available because the YouTube account associated with this video has been terminated." => Youtube::AccountTerminated,
-                        "This video is unavailable" => Youtube::NotFound,
-                        "This video has been removed by the uploader" => Youtube::RemovedByUploader,
-                        "This video is no longer available due to a copyright claim by " => {
-                            if let Some(Subreason::Runs(runs)) = &renderer.subreason {
-                                let claiment = runs.runs[1].text.clone();
-                                Youtube::CopyrightClaim {claiment}
-                            } else {
-                                unreachable!("copyright claim error screen did was not Runs")
-                            }
-                        }
-                        e => unimplemented!("Unknown subreason for video unavailable: '{}'", e),
-                    },
-                    "Sign in to confirm your age" => Youtube::AgeRestricted,
-                    "This video has been removed for violating YouTube's policy on nudity or sexual content." => Youtube::NudityOrSexualContentViolation,
-                    "This video has been removed for violating YouTube's Terms of Service." => Youtube::TermsOfServiceViolation,
-                    "This video requires payment to watch." => Youtube::PurchaseRequired,
-                    e => unimplemented!("Unknown error screen text: '{}'", e)
+        match self.reason.as_str() {
+            "This video is unavailable." => Youtube::NotFound,
+            "This video is no longer available because the YouTube account associated with this video has been terminated." => Youtube::AccountTerminated,
+            "This video has been removed by the uploader" => Youtube::RemovedByUploader,
+            "This video has been removed for violating YouTube's policy on nudity or sexual content." => Youtube::NudityOrSexualContentViolation,
+            "This video is private." => Youtube::Private,
+            "This video has been removed for violating YouTube's Terms of Service." => Youtube::TermsOfServiceViolation,
+            "This video requires payment to watch." => Youtube::PurchaseRequired,
+            "This video may be inappropriate for some users." => Youtube::AgeRestricted,
+            copyright if copyright.starts_with("This video is no longer available due to a copyright claim by") => {
+                let who = copyright.strip_prefix("This video is no longer available due to a copyright claim by ").unwrap().strip_suffix('.').unwrap();
+                Youtube::CopyrightClaim {
+                    claiment: who.to_string()
                 }
-            },
-            (Some(reason), _) => {
-                match reason.as_str() {
-                    "This video requires payment to watch." => Youtube::PurchaseRequired,
-                    e => unimplemented!("Unknown error reason: '{}'", e),
-                }
-            },
-            e => todo!("{:#?}", e),
+            }
+            unknown => unimplemented!("Unknown error reason: `{}`", unknown),
         }
     }
 }
-
-#[derive(Debug, serde::Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct ErrorScreen {
-    pub player_error_message_renderer: Option<PlayerErrorMessageRenderer>,
-}
-
-#[derive(Debug, serde::Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct PlayerErrorMessageRenderer {
-    pub reason: SimpleText,
-    subreason: Option<Subreason>,
-}
-
-impl PlayerErrorMessageRenderer {
-    fn subreason(&self) -> Option<&str> {
-        match self.subreason.as_ref()? {
-            Subreason::SimpleText(text) => Some(text.simple_text.as_str()),
-            Subreason::Runs(runs) => Some(runs.runs.get(0)?.text.as_str()),
-        }
-    }
-}
-
-#[derive(Debug, serde::Deserialize)]
-#[serde(rename_all = "camelCase", untagged)]
-pub enum Subreason {
-    SimpleText(SimpleText),
-    Runs(Runs),
-}
-
-#[derive(Debug, serde::Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct SimpleText {
-    pub simple_text: String,
-}
-
-#[derive(Debug, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct Runs {
-    pub runs: Vec<TitleRun>,
-}
-
-#[derive(Debug, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct TitleRun {
-    pub text: String,
-}
